'use client';
import { useState, useEffect } from "react";
import { account } from "./lib/appwrite";
import { useRouter, usePathname } from "next/navigation";
import Sidebar from "./components/Sidebar";
import Navbar from "./components/Navbar";
import { Menu } from 'lucide-react';

export default function ClientLayout({ children }) {
  const [isSidebarCollapsed, setIsSidebarCollapsed] = useState(false);
  const [isMobileOpen, setIsMobileOpen] = useState(false);
  const [isLoggedIn, setIsLoggedIn] = useState(false);
  const [loading, setLoading] = useState(true);
  const router = useRouter();
  const pathname = usePathname();

  // List of routes where we don't want sidebar/navbar
  const authRoutes = ['/login', '/register', '/forgot-password'];

  useEffect(() => {
    const checkAuth = async () => {
      try {
        await account.get();
        setIsLoggedIn(true);
        
        // If on auth route but logged in, redirect to dashboard
        if (authRoutes.includes(pathname)) {
          router.push('/dashboard');
        }
      } catch (error) {
        setIsLoggedIn(false);
        
        // If not on auth route and not logged in, redirect to login
        if (!authRoutes.includes(pathname)) {
          router.push('/login');
        }
      } finally {
        setLoading(false);
      }
    };
    checkAuth();
  }, [router, pathname]);

  const toggleMobileSidebar = () => {
    setIsMobileOpen(!isMobileOpen);
  };

  if (loading) {
    return <div className="flex items-center justify-center min-h-screen">Loading...</div>;
  }

  // If on auth route, render only the children without layout
  if (authRoutes.includes(pathname)) {
    return (
      <div className="min-h-screen bg-gray-50">
        {children}
      </div>
    );
  }

  // If not logged in but not on auth route (shouldn't happen due to redirect above)
  if (!isLoggedIn) {
    return null; // or redirect to login
  }

  // Normal layout with sidebar and navbar
  return (
    <div className="flex min-h-screen">
      {/* Mobile Toggle Button */}
      <button
        onClick={toggleMobileSidebar}
        className="md:hidden fixed top-4 left-4 z-50 bg-white dark:bg-gray-800 p-2 rounded-md shadow-md"
      >
        <Menu size={24} />
      </button>

      <Sidebar 
        isCollapsed={isSidebarCollapsed}
        isMobileOpen={isMobileOpen}
        toggleMobileSidebar={toggleMobileSidebar}
      />
      
      <div className={`flex-1 flex flex-col transition-all duration-300 ${
        isSidebarCollapsed ? 'md:pl-20' : 'md:pl-64'
      }`}>
        <Navbar 
          isSidebarCollapsed={isSidebarCollapsed}
          toggleSidebar={() => setIsSidebarCollapsed(!isSidebarCollapsed)} 
        />
        
        <main className="flex-1 p-4 md:p-6 overflow-auto">
          {children}
        </main>
      </div>
    </div>
  );
}