'use client';

import { useState, useEffect } from "react";
import { databases, ID, databaseId, membersCollectionId, Query } from "../lib/appwrite";
import { getCurrentUserWithRole } from "../utils/auth";

export default function MemberForm() {
  const [currentUser, setCurrentUser] = useState(null);
  const [loading, setLoading] = useState(true);
  const [form, setForm] = useState({
    name: "",
    email: "",
    phone: "",
    role: "member",
    joinDate: new Date().toISOString().split('T')[0],
  });
  const [error, setError] = useState("");

  useEffect(() => {
    const fetchCurrentUser = async () => {
      try {
        const user = await getCurrentUserWithRole();
        setCurrentUser(user);
        
        setForm(prev => ({
          ...prev,
          name: user.name || "",
          email: user.email || ""
        }));
      } catch (err) {
        console.error("Failed to fetch current user:", err);
        setError("Failed to load user data");
      } finally {
        setLoading(false);
      }
    };

    fetchCurrentUser();
  }, []);

  const checkDuplicateEmail = async (email) => {
    try {
      const response = await databases.listDocuments(
        databaseId,
        membersCollectionId,
        [Query.equal("email", email)]
      );
      return response.documents.length > 0;
    } catch (err) {
      console.error("Error checking duplicate email:", err);
      return false;
    }
  };

  const handleChange = (e) => {
    setForm({ ...form, [e.target.name]: e.target.value });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setError("");

    // Validate email matches current user
    if (form.email !== currentUser?.email) {
      setError("You must use your registered email address");
      return;
    }

    // Check for duplicate entry
    const isDuplicate = await checkDuplicateEmail(form.email);
    if (isDuplicate) {
      setError("This email is already registered as a member");
      return;
    }

    try {
      await databases.createDocument(
        databaseId,
        membersCollectionId,
        ID.unique(),
        form
      );
      alert("Member added successfully!");
      setForm(prev => ({
        ...prev,
        phone: "",
        role: "member",
        joinDate: new Date().toISOString().split('T')[0]
      }));
    } catch (err) {
      console.error("Failed to add member:", err);
      setError("Failed to add member. Please try again.");
    }
  };

  if (loading) {
    return <div className="text-center p-4">Loading form...</div>;
  }

  return (
    <div className="max-w-2xl mx-auto p-6 bg-white rounded-lg shadow-md">
      <h2 className="text-xl font-semibold mb-4">Add New Member</h2>
      
      {error && (
        <div className="mb-4 p-3 bg-red-100 text-red-700 rounded-md">
          {error}
        </div>
      )}

<form onSubmit={handleSubmit} className="space-y-4">
  {/* First Row - Name and Email */}
  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
    {/* Name Field */}
    <div>
      <label className="block text-sm font-medium text-gray-700 mb-1">Name</label>
      <div className="relative">
        <input
          name="name"
          value={form.name}
          className="w-full px-3 py-1.5 border rounded-md bg-gray-100 text-sm"
          readOnly
        />
        <div className="absolute inset-y-0 right-0 flex items-center pr-3 pointer-events-none">
          <span className="text-gray-500 text-xs">(your account name)</span>
        </div>
      </div>
    </div>
    
    {/* Email Field */}
    <div>
      <label className="block text-sm font-medium text-gray-700 mb-1">Email</label>
      <div className="relative">
        <input
          type="email"
          name="email"
          value={form.email}
          className="w-full px-3 py-1.5 border rounded-md bg-gray-100 text-sm"
          readOnly
        />
        <div className="absolute inset-y-0 right-0 flex items-center pr-3 pointer-events-none">
          <span className="text-gray-500 text-xs">(your login email)</span>
        </div>
      </div>
    </div>
  </div>

  {/* Second Row - Phone and Role */}
  <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
    {/* Phone Field */}
    <div>
      <label className="block text-sm font-medium text-gray-700 mb-1">Phone</label>
      <input
        name="phone"
        value={form.phone}
        onChange={handleChange}
        placeholder="Enter phone number"
        className="w-full px-3 py-1.5 border rounded-md text-sm"
      />
    </div>
    
    {/* Role Field */}
    <div>
      <label className="block text-sm font-medium text-gray-700 mb-1">Role</label>
      <select
        name="role"
        value={form.role}
        onChange={handleChange}
        className="w-full px-3 py-1.5 border rounded-md text-sm"
      >
        <option value="member">Member</option>
        <option value="admin">Admin</option>
      </select>
    </div>
  </div>

  {/* Join Date Field */}
  <div>
    <label className="block text-sm font-medium text-gray-700 mb-1">Join Date</label>
    <input
      type="date"
      name="joinDate"
      value={form.joinDate}
      onChange={handleChange}
      className="w-full px-3 py-1.5 border rounded-md text-sm"
    />
  </div>
  
  <button
    type="submit"
    className="w-full bg-blue-600 text-white py-1.5 px-4 rounded-md hover:bg-blue-700 transition text-sm"
  >
    Add Member
  </button>
</form>

    </div>
  );
}